@@ -336,6 +336,9 @@ class JobData(object):
         """
         if self.status in ["RUNNING", "COMPLETED", "FAILED"]:
             # print("Finish: {0}".format(self.finish))
+            if self.start == 0:
+                return 0
+
             run = int((self.finish if self.finish >
                        0 else time.time()) - self.start)
             # print("RUN {0}".format(run))
